@@ -16,16 +16,16 @@ from cx_Freeze.finder import Module, ModuleFinder
 from cx_Freeze.freezer import ConstantsModule, Freezer
 
 __all__ = [
-    "build_exe",
-    "install",
-    "install_exe",
-    "setup",
     "ConstantsModule",
     "Executable",
     "Freezer",
     "Module",
     "ModuleFinder",
     "__version__",
+    "build_exe",
+    "install",
+    "install_exe",
+    "setup",
 ]
 
 if sys.platform == "win32":
@@ -33,7 +33,8 @@ if sys.platform == "win32":
 
     __all__ += ["bdist_msi"]
 elif sys.platform == "darwin":
-    from cx_Freeze.command.bdist_mac import bdist_dmg, bdist_mac
+    from cx_Freeze.command.bdist_dmg import bdist_dmg
+    from cx_Freeze.command.bdist_mac import bdist_mac
 
     __all__ += ["bdist_dmg", "bdist_mac"]
 else:
@@ -44,7 +45,7 @@ else:
     __all__ += ["bdist_appimage", "bdist_deb", "bdist_rpm"]
 
 
-__version__ = "7.1.1"
+__version__ = "7.2.8"
 
 
 def setup(**attrs) -> setuptools.Distribution:  # noqa: D103
